==> haskell-summoner-tui-2.0.1.1-611-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-5PebqsDdK19AmGhh8SPCCd
key:                  summoner-tui-2.0.1.1-5PebqsDdK19AmGhh8SPCCd
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  317483982a5f096a3d37c3b2762b9c36
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-5PebqsDdK19AmGhh8SPCCd
depends:
    base-4.17.2.1 relude-1.2.2.0-Hx1ns9TCJrN3Ygt73ZoWV
    brick-0.71.1-2fV4RkdFcY4ImIkJX8H7f7
    colourista-0.1.0.2-5zam9Rhrqjo1wsLFNOX85Q directory-1.3.7.1
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-GNytIaHmI1f32SxxcUFLLO
    summoner-2.0.1.1-6o3mPQXMJKSLObLN6Rdxox
    validation-selective-0.2.0.0-KxvHbhLbRxGBAKaNuAgKBK
    vty-5.39-1vKuOHHYLqm6EqaDJUxoGk

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-tui-2.0.1.1-613-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-AVLrHZIofou9HJlsavOLSX
key:                  summoner-tui-2.0.1.1-AVLrHZIofou9HJlsavOLSX
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  bd3c1165921581551745a0512e72e5ca
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-AVLrHZIofou9HJlsavOLSX
depends:
    base-4.17.2.1 relude-1.2.2.0-Hx1ns9TCJrN3Ygt73ZoWV
    brick-0.71.1-2fV4RkdFcY4ImIkJX8H7f7
    colourista-0.1.0.2-5zam9Rhrqjo1wsLFNOX85Q directory-1.3.7.1
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-GNytIaHmI1f32SxxcUFLLO
    summoner-2.0.1.1-40s7kLp6KEBKLbwzzTnU02
    validation-selective-0.2.0.0-KxvHbhLbRxGBAKaNuAgKBK
    vty-5.39-1vKuOHHYLqm6EqaDJUxoGk

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
